==> haskell-text-conversions-0.3.1.1-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-conversions
version:              0.3.1.1
visibility:           public
id:                   text-conversions-0.3.1.1-FBVcHOZzc3U70XD8UhXTlf
key:                  text-conversions-0.3.1.1-FBVcHOZzc3U70XD8UhXTlf
license:              ISC
maintainer:           Alexis King <lexi.lambda@gmail.com>
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  b652d947a9867a9aaf5739301813ccbc
exposed:              True
exposed-modules:      Data.Text.Conversions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-conversions
hs-libraries:         HStext-conversions-0.3.1.1-FBVcHOZzc3U70XD8UhXTlf
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-4RSPY9wdSACLYMQREwRCeE
    base64-bytestring-1.2.1.0-6q4Jlow4UI5PGuVolnxGn bytestring-0.11.5.3
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-conversions-0.3.1.1-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-conversions
version:              0.3.1.1
visibility:           public
id:                   text-conversions-0.3.1.1-JxtDN11xXJ0HCetQva2Wga
key:                  text-conversions-0.3.1.1-JxtDN11xXJ0HCetQva2Wga
license:              ISC
maintainer:           Alexis King <lexi.lambda@gmail.com>
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  c1f03e5487b33bdd906633aa2c3a311f
exposed:              True
exposed-modules:      Data.Text.Conversions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-conversions-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-conversions
hs-libraries:         HStext-conversions-0.3.1.1-JxtDN11xXJ0HCetQva2Wga
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-FFyoh3BEwBDECdSU16X13M
    base64-bytestring-1.2.1.0-AbhqXNvtZOJLR3Ub6lZ1hd
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
